pub enum Quantity {
ApparentSize,
BlockSize,
BlockCount,
}Expand description
Quantity to be measured.
Variants
ApparentSize
Measure apparent sizes, equivalent to the len method.
BlockSize
Measure block sizes, equivalent to the blksize method (POSIX only).
BlockCount
Count numbers of blocks, equivalent to the blocks method (POSIX only).