#[non_exhaustive]pub struct Args {Show 19 fields
pub files: Vec<PathBuf>,
pub json_input: bool,
pub json_output: bool,
pub bytes_format: BytesFormat,
pub deduplicate_hardlinks: bool,
pub one_file_system: bool,
pub top_down: bool,
pub align_right: bool,
pub quantity: Quantity,
pub max_depth: Depth,
pub total_width: Option<usize>,
pub column_width: Option<Vec<usize>>,
pub min_ratio: Fraction,
pub no_sort: bool,
pub silent_errors: bool,
pub progress: bool,
pub threads: Threads,
pub omit_json_shared_details: bool,
pub omit_json_shared_summary: bool,
}Expand description
The CLI arguments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.files: Vec<PathBuf>List of files and/or directories.
json_input: boolRead JSON data from stdin.
json_output: boolPrint JSON data instead of an ASCII chart.
bytes_format: BytesFormatHow to display the numbers of bytes.
deduplicate_hardlinks: boolDetect and subtract the sizes of hardlinks from their parent directory totals.
one_file_system: boolSkip directories on different filesystems.
top_down: boolPrint the tree top-down instead of bottom-up.
align_right: boolSet the root of the bars to the right.
quantity: QuantityAspect of the files/directories to be measured.
max_depth: DepthMaximum depth to display the data. Could be either “inf” or a positive integer.
total_width: Option<usize>Width of the visualization.
column_width: Option<Vec<usize>>Maximum widths of the tree column and width of the bar column.
min_ratio: FractionMinimal size proportion required to appear.
no_sort: boolDo not sort the branches in the tree.
silent_errors: boolPrevent filesystem error messages from appearing in stderr.
progress: boolReport progress being made at the expense of performance.
threads: ThreadsSet the maximum number of threads to spawn. Could be either “auto”, “max”, or a positive integer.
Do not output .shared.details in the JSON output.
Do not output .shared.summary in the JSON output.
Implementations
Sourceimpl Args
impl Args
Sourcepub fn with_files(self, value: Vec<PathBuf>) -> Self
pub fn with_files(self, value: Vec<PathBuf>) -> Self
Sets the files field of this struct.
Sourcepub fn with_json_input(self, value: bool) -> Self
pub fn with_json_input(self, value: bool) -> Self
Sets the json_input field of this struct.
Sourcepub fn with_json_output(self, value: bool) -> Self
pub fn with_json_output(self, value: bool) -> Self
Sets the json_output field of this struct.
Sourcepub fn with_bytes_format(self, value: BytesFormat) -> Self
pub fn with_bytes_format(self, value: BytesFormat) -> Self
Sets the bytes_format field of this struct.
Sourcepub fn with_deduplicate_hardlinks(self, value: bool) -> Self
pub fn with_deduplicate_hardlinks(self, value: bool) -> Self
Sets the deduplicate_hardlinks field of this struct.
Sourcepub fn with_one_file_system(self, value: bool) -> Self
pub fn with_one_file_system(self, value: bool) -> Self
Sets the one_file_system field of this struct.
Sourcepub fn with_top_down(self, value: bool) -> Self
pub fn with_top_down(self, value: bool) -> Self
Sets the top_down field of this struct.
Sourcepub fn with_align_right(self, value: bool) -> Self
pub fn with_align_right(self, value: bool) -> Self
Sets the align_right field of this struct.
Sourcepub fn with_quantity(self, value: Quantity) -> Self
pub fn with_quantity(self, value: Quantity) -> Self
Sets the quantity field of this struct.
Sourcepub fn with_max_depth(self, value: Depth) -> Self
pub fn with_max_depth(self, value: Depth) -> Self
Sets the max_depth field of this struct.
Sourcepub fn with_total_width(self, value: Option<usize>) -> Self
pub fn with_total_width(self, value: Option<usize>) -> Self
Sets the total_width field of this struct.
Sourcepub fn with_column_width(self, value: Option<Vec<usize>>) -> Self
pub fn with_column_width(self, value: Option<Vec<usize>>) -> Self
Sets the column_width field of this struct.
Sourcepub fn with_min_ratio(self, value: Fraction) -> Self
pub fn with_min_ratio(self, value: Fraction) -> Self
Sets the min_ratio field of this struct.
Sourcepub fn with_no_sort(self, value: bool) -> Self
pub fn with_no_sort(self, value: bool) -> Self
Sets the no_sort field of this struct.
Sourcepub fn with_silent_errors(self, value: bool) -> Self
pub fn with_silent_errors(self, value: bool) -> Self
Sets the silent_errors field of this struct.
Sourcepub fn with_progress(self, value: bool) -> Self
pub fn with_progress(self, value: bool) -> Self
Sets the progress field of this struct.
Sourcepub fn with_threads(self, value: Threads) -> Self
pub fn with_threads(self, value: Threads) -> Self
Sets the threads field of this struct.
Sets the omit_json_shared_details field of this struct.
Sets the omit_json_shared_summary field of this struct.