pub enum BytesFormat {
PlainNumber,
MetricUnits,
BinaryUnits,
}Expand description
The DisplayFormat type of Bytes.
Variants
PlainNumber
Display the value as-is.
MetricUnits
Display the value with a unit suffix in metric scale.
BinaryUnits
Display the value with a unit suffix in binary scale.
Implementations