pub struct Reflection<Name, Data: Size> {
    pub name: Name,
    pub data: Data,
    pub children: Vec<Self>,
}
Intermediate format used for construction and inspection of DataTree’s internal content.

Unlike Tree where the fields are all private, the fields of TreeReflection are all public to allow construction in tests.

Conversion between DataTree and Reflection:

  • Any DataTree can be safely transmuted to a valid Reflection.
  • Any Reflection can be safely transmuted to a potentially invalid DataTree.
  • To safely convert a DataTree into a Reflection without the unsafe keyword, use DataTree::into_reflection (it would be slower than using transmute).
  • To safely convert a Reflection into a valid DataTree, use par_try_into_tree.

Serialization and deserialization: (feature: json) Reflection implements Serialize and Deserialize traits, this allows functions in serde_json to convert a Reflection into/from JSON.

Fields

name: Name

Name of the tree.

data: Data

Disk usage of a file or total disk usage of a folder.

children: Vec<Self>

Data of children filesystem subtrees.

Implementations

Attempting to convert a Reflection into a valid DataTree.

Attempt to transform names and data.

Attempt to convert all names from OsString to String.