pub struct DataTree<Name, Data: Size> { /* private fields */ }
Disk usage data of a filesystem tree.

Construction: There are 3 main ways to create a DataTree:

Visualization: Use the Visualizer struct to create an ASCII chart that visualizes DataTree.

Serialization and deserialization: (feature: json) DataTree does not implement Serialize and Deserialize traits directly, instead, it can be converted into/from a Reflection which implements these traits.

Implementations

Create reflection.

Create a tree representation of a directory.

Create a tree representation of a file.

Create a directory constructor of fixed inode size.

Extract name

Get mutable reference to name.

Extract total disk usage

Extract children

Recursively cull all descendants that do not satisfy given predicate, in parallel.

Process the tree via par_retain method.

Recursively cull all descendants whose data are too small relative to root.

Sort all descendants recursively, in parallel.

Process the tree via par_sort_by method.