pub trait DeduplicateSharedSize<Size: Size>: Sized {
type Report;
type Error;
// Required method
fn deduplicate(
self,
data_tree: &mut DataTree<OsStringDisplay, Size>,
) -> Result<Self::Report, Self::Error>;
}Expand description
Ability to correct the sizes in a DataTree by reducing the size of recorded shared links.
The input tree is assumed to be not yet deduplicated.
Required Associated Types
Sourcetype Report
type Report
Report returned when DeduplicateSharedSize::deduplicate succeeds.
Sourcetype Error
type Error
Error returned when DeduplicateSharedSize::deduplicate fails.
Required Methods
Sourcefn deduplicate(
self,
data_tree: &mut DataTree<OsStringDisplay, Size>,
) -> Result<Self::Report, Self::Error>
fn deduplicate( self, data_tree: &mut DataTree<OsStringDisplay, Size>, ) -> Result<Self::Report, Self::Error>
Correct the sizes in a DataTree by reducing the size of recorded shared links.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".