Re-exports
pub use iter::Iter;pub use reflection::Reflection;pub use summary::Summary;pub use Reflection as HardlinkListReflection;
Modules
Structs
- Hardlink
List - Storage to be used by
crate::hardlink::RecordHardlinks. - Number
OfLinks Conflict Error - Error that occurs when a different
nlinkwas detected for the sameinoanddev. - Size
Conflict Error - Error that occurs when a different size was detected for the same
inoanddev.
Enums
- AddError
- Error that occurs when it fails to add an item to
HardlinkList.