Summary

Struct Summary 

#[non_exhaustive]
pub struct Summary<Size> { pub inodes: usize, pub exclusive_inodes: usize, pub all_links: u64, pub detected_links: usize, pub exclusive_links: usize, pub shared_size: Size, pub exclusive_shared_size: Size, }
Summary from HardlinkList or Reflection.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
inodes: usize

Number of shared inodes, each with more than 1 links (i.e. nlink > 1).

exclusive_inodes: usize

Number of shared inodes that don’t have links outside the measured tree.

This number is expected to be less than or equal to Self::inodes.

all_links: u64

Totality of the numbers of links of all shared inodes.

detected_links: usize

Total number of links of shared inodes that were detected within the measured tree.

This number is expected to be less than or equal to Self::all_links.

exclusive_links: usize

Total number of links of shared inodes that don’t have links outside the measured tree.

This number is expected to be less than or equal to Self::detected_links.

shared_size: Size

Totality of the sizes of all shared inodes.

exclusive_shared_size: Size

Totality of the sizes of all shared inodes that don’t have links outside the measured tree.

This number is expected to be less than or equal to Self::all_links.

Implementations

Source

impl<Size> Summary<Size>

pub fn with_inodes(self, value: usize) -> Self

Sets the inodes field of this struct.

pub fn with_exclusive_inodes(self, value: usize) -> Self

Sets the exclusive_inodes field of this struct.

Sets the all_links field of this struct.

Sets the detected_links field of this struct.

Sets the exclusive_links field of this struct.

pub fn with_shared_size(self, value: Size) -> Self

Sets the shared_size field of this struct.

pub fn with_exclusive_shared_size(self, value: Size) -> Self

Sets the exclusive_shared_size field of this struct.

Source

impl<Size: Size> Summary<Size>

pub fn display(&self, format: Size::DisplayFormat) -> SummaryDisplay<'_, Size>

Turns this Summary into something displayable.