pub enum ColumnWidthDistribution {
    Total {
        width: usize,
    },
    Components {
        tree_column_max_width: usize,
        bar_column_width: usize,
    },
}
Specify distribution and total number of characters/blocks can be placed in a line.

Variants

Total

Fields

width: usize

Total number of characters/blocks can be placed in a line.

Specify total number of characters/blocks can be placed in a line.

Components

Fields

tree_column_max_width: usize

Maximum number of characters/blocks can be placed in a line for the filesystem tree visualization.

bar_column_width: usize

Number of characters/blocks can be placed in a line for the proportion bar.

Specify (maximum) number of characters/blocks can be placed in a line for each individual component of the visualization.

Implementations

Specify total number of characters/blocks can be placed in a line.

Specify maximum number of characters/blocks can be placed in a line for each individual component of the visualization.