Enum parallel_disk_usage::visualizer::direction::Direction
source · [−]pub enum Direction {
BottomUp,
TopDown,
}Expand description
The direction of the visualization of the tree.
Variants
BottomUp
The root of the tree is placed at the bottom of the visualization.
TopDown
The root of the tree is placed at the top of the visualization.