Struct parallel_disk_usage::visualizer::tree::TreeHorizontalSlice
source · [−]pub struct TreeHorizontalSlice<Name: Width> { /* private fields */ }Expand description
Horizontal slice of a tree of the height of exactly 1 line of text.
Implementations
sourceimpl TreeHorizontalSlice<String>
impl TreeHorizontalSlice<String>
sourcepub fn truncate(&mut self, max_width: usize) -> Result<(), usize>
pub fn truncate(&mut self, max_width: usize) -> Result<(), usize>
Truncate the name to fit specified max_width.
- If
max_widthis already sufficient, do nothing other than returnOk(()). - If
max_widthis insufficient even for the required part, returnErr(N)whereNis the required width. - If
max_widthis sufficient for the required part but insufficient for the name, truncate and add"..."to the name.