Struct parallel_disk_usage::visualizer::tree::TreeSkeletalComponent
source · [−]pub struct TreeSkeletalComponent {
pub child_position: ChildPosition,
pub direction: Direction,
pub parenthood: Parenthood,
}Expand description
Determine 3 characters to use as skeletal component that connect a node to the rest of the tree.
Fields
child_position: ChildPositionWhether the node is the last child amongst its parent’s children.
direction: DirectionThe direction of the visualization of the tree.
parenthood: ParenthoodWhether the node has children.
Implementations
sourceimpl TreeSkeletalComponent
impl TreeSkeletalComponent
sourcepub const fn visualize(self) -> TreeSkeletalComponentVisualization
pub const fn visualize(self) -> TreeSkeletalComponentVisualization
Determine 3 characters to use as skeletal component that connect a node to the rest of the tree.