pub struct Args {
Show 14 fields pub files: Vec<PathBuf>, pub json_input: bool, pub json_output: bool, pub bytes_format: BytesFormat, pub top_down: bool, pub align_left: bool, pub quantity: Quantity, pub max_depth: NonZeroUsize, pub total_width: Option<usize>, pub column_width: Option<Vec<usize>>, pub min_ratio: Fraction, pub no_sort: bool, pub silent_errors: bool, pub progress: bool,
}
The CLI arguments.

Fields

files: Vec<PathBuf>

List of files and/or directories.

json_input: bool

Read JSON data from stdin.

json_output: bool

Print JSON data instead of an ASCII chart.

bytes_format: BytesFormat

How to display the numbers of bytes.

top_down: bool

Print the tree top-down instead of bottom-up.

align_left: bool

Fill the bars from left to right.

quantity: Quantity

Aspect of the files/directories to be measured.

max_depth: NonZeroUsize

Maximum depth to display the data (must be greater than 0).

total_width: Option<usize>

Width of the visualization.

column_width: Option<Vec<usize>>

Maximum widths of the tree column and width of the bar column.

min_ratio: Fraction

Minimal size proportion required to appear.

no_sort: bool

Preserve order of entries.

silent_errors: bool

Prevent filesystem error messages from appearing in stderr.

progress: bool

Report progress being made at the expense of performance.