Module hardlink_list

Module hardlink_list 

Re-exports

pub use iter::Iter;
pub use reflection::Reflection;
pub use summary::Summary;
pub use Reflection as HardlinkListReflection;
pub use Summary as SharedLinkSummary;

Modules

iter
reflection
summary

Structs

HardlinkList
Storage to be used by crate::hardlink::RecordHardlinks.
NumberOfLinksConflictError
Error that occurs when a different nlink was detected for the same ino and dev.
SizeConflictError
Error that occurs when a different size was detected for the same ino and dev.

Enums

AddError
Error that occurs when it fails to add an item to HardlinkList.