#[non_exhaustive]pub struct Summary<Size> {
pub inodes: usize,
pub exclusive_inodes: usize,
pub all_links: u64,
pub detected_links: usize,
pub exclusive_links: usize,
pub shared_size: Size,
pub exclusive_shared_size: Size,
}Expand description
Summary from HardlinkList or Reflection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inodes: usizeNumber of shared inodes, each with more than 1 links (i.e. nlink > 1).
exclusive_inodes: usizeNumber of shared inodes that don’t have links outside the measured tree.
This number is expected to be less than or equal to Self::inodes.
all_links: u64Totality of the numbers of links of all shared inodes.
detected_links: usizeTotal number of links of shared inodes that were detected within the measured tree.
This number is expected to be less than or equal to Self::all_links.
exclusive_links: usizeTotal number of links of shared inodes that don’t have links outside the measured tree.
This number is expected to be less than or equal to Self::detected_links.
Totality of the sizes of all shared inodes.
Totality of the sizes of all shared inodes that don’t have links outside the measured tree.
This number is expected to be less than or equal to Self::all_links.
Implementations
Sourceimpl<Size> Summary<Size>
impl<Size> Summary<Size>
Sourcepub fn with_inodes(self, value: usize) -> Self
pub fn with_inodes(self, value: usize) -> Self
Sets the inodes field of this struct.
Sourcepub fn with_exclusive_inodes(self, value: usize) -> Self
pub fn with_exclusive_inodes(self, value: usize) -> Self
Sets the exclusive_inodes field of this struct.
Sourcepub fn with_all_links(self, value: u64) -> Self
pub fn with_all_links(self, value: u64) -> Self
Sets the all_links field of this struct.
Sourcepub fn with_detected_links(self, value: usize) -> Self
pub fn with_detected_links(self, value: usize) -> Self
Sets the detected_links field of this struct.
Sourcepub fn with_exclusive_links(self, value: usize) -> Self
pub fn with_exclusive_links(self, value: usize) -> Self
Sets the exclusive_links field of this struct.
Sets the shared_size field of this struct.
Sets the exclusive_shared_size field of this struct.
Sourceimpl<Size: Size> Summary<Size>
impl<Size: Size> Summary<Size>
Sourcepub fn display(&self, format: Size::DisplayFormat) -> SummaryDisplay<'_, Size>
pub fn display(&self, format: Size::DisplayFormat) -> SummaryDisplay<'_, Size>
Turns this Summary into something displayable.