Enum parallel_disk_usage::visualizer::column_width_distribution::ColumnWidthDistribution
source · [−]pub enum ColumnWidthDistribution {
Total {
width: usize,
},
Components {
tree_column_max_width: usize,
bar_column_width: usize,
},
}Expand description
Specify distribution and total number of characters/blocks can be placed in a line.
Variants
Total
Fields
width: usizeTotal number of characters/blocks can be placed in a line.
Specify total number of characters/blocks can be placed in a line.
Components
Fields
tree_column_max_width: usizeMaximum number of characters/blocks can be placed in a line for the filesystem tree visualization.
bar_column_width: usizeNumber of characters/blocks can be placed in a line for the proportion bar.
Specify (maximum) number of characters/blocks can be placed in a line for each individual component of the visualization.
Implementations
sourceimpl ColumnWidthDistribution
impl ColumnWidthDistribution
sourcepub const fn total(width: usize) -> Self
pub const fn total(width: usize) -> Self
Specify total number of characters/blocks can be placed in a line.
sourcepub const fn components(
tree_column_max_width: usize,
bar_column_width: usize
) -> Self
pub const fn components(
tree_column_max_width: usize,
bar_column_width: usize
) -> Self
Specify maximum number of characters/blocks can be placed in a line for each individual component of the visualization.